%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%  Class file for submission to the Jounal of the Japan Society of
%  Microgravity Application (JASMA).
%
%  Coded by the editorial board of the JASMA in July 2012.
%
%  Change Log
%  24 July 2012 : Ver.0.1   by S. Adachi
%  25 July 2012 : Ver.0.11  by S. Adachi
%    Keyword left margin is adjusted.
%    Natbib options for newer version are adjusted.
%  20 Aug. 2012 : Ver.0.12  by S. Adachi
%    \toppageheader command is changed to having 4 arguments.
%    \localpage command is added.
%    Reviced: Appendix format and header at the first page.
%    Bug fix: Footer bugs when the first page is even.
%  21 Aug. 2012 : Ver.0.13  by S. Adachi
%    Bug Fix: Excess line spaces of tabcenter and figcenter.
%  17 Feb. 2014 : Ver.0.14 by S. Adachi
%    Added: \affcomma for multiple affiliations at the Author line
%    Modified: Basically, there is no need to place the command \addfootnotespace in the second column at the first page.
%        The additional foot space will be inserted automatically if the paragraph exists in the second column.
%        \addfootnotespace is still kept for the cases where there are no paragraphs in the second column.
%    Modified: \footnote will work normally except for the first and last pages but the style is the same as the usual LaTeX.
%  22 Apr. 2014: Ver.0.15 by S. Adachi
%    Modified: \appendix command now has one argument, for example, \appendix[2]{}, \appendix{Header Description} or so.
%        This is useful to add a title for the appendix. Please note that there is another way by using command \append
%        in cases of multiple appendix sections.
%  29 Oct. 2014: Ver.0.20 by S. Adachi
%    Modified: Page layput is changed to match with modern online journals.
%    Modified: Outdated flushend package is no longer used but balance package is used.
%                 Flushend package causes serious layout bugs with TeXLive2014.
%    Modified: Line spacings at footers and headers are fine tuned.
%    Added: Hyperlinks is now available by including hyperref package.
%  11 Nov. 2014: Ver.0.21 by S. Adachi
%    Modified: Locations of received and accepted dates are moved to the top page.
%    Modified: Published date is added.
%    Modified: Small changes of commands due to modifications of dates and aux output.
%  12 Nov. 2014: Ver.0.22 by S. Adachi
%    Modified: Fixed potential bugs of header and footer on the top page.
%    Modified: Fixed potential bugs of received, accepted and published dates.
%  05 Dec. 2014: Ver.0.23 by S. Adachi
%    Modified: Fixed layout bugs of caption with multiple lines.
%  08 Jan. 2015: Ver.0.24 by S. Adachi
%    Improved: Bottom space at the first page is improved so that the adjustment can be adapted to more cases .
%    Modified: Upper and lower spaces of the section is made little smaller.
%  10 Jul. 2015: Ver.0.25 by S. Adachi
%    Bug fix: Miscalculation of the footnote height if the affiliation is long and thus the number of lines become multiple.
%        As a result, the additional command \addfootnotespace may not be necessary any more.
%    Modified: Argument of \addfootnotespace is changed to count the existing footnote height.
%        Thus, the argument is the additional height to be added to the automatic calculated height.
%    Modified: Vertical space between the section and subsection headers is fine-tuned.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}%  LaTeX 2.09 is not allowed
[2005/12/01]%  Document date must be 2005/12/01 or later
\ProvidesClass{jasma}[2015/01/08 JASMA ver.0.24]%  \fileversion

%
% Declaration
%
\DeclareOption{a4paper}{%
  \setlength\paperheight{297mm}
  \setlength\paperwidth{210mm}
}
\DeclareOption{twoside}{\@twosidetrue \@mparswitchtrue}
\DeclareOption{twocolumn}{\@twocolumntrue}

\PassOptionsToClass{a4paper,twocolumn,twoside,fleqn}{article}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions
\LoadClass{article}
\RequirePackage{amsmath}
%\RequirePackage[round,numbers,super,comma,sort&compress]{natbib}
\RequirePackage[round,super,comma,sort&compress]{natbib}
%\bibpunct{}{)}{,}{^n}{,}{,}
\bibpunct{}{)}{,}{s}{,}{,}
%\RequirePackage[autobase]{flushend}
\RequirePackage{balance}

%
% Hyperlinks imported from hyperref
%


%
% definitions of font sizes
% multiplier: 1.483
%
\renewcommand\normalsize{%
%  \@setfontsize\normalsize\@ixpt{13.3}
  \fontsize{9.0pt}{13.3pt}\selectfont
  \abovedisplayskip 11.4\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus2\p@
  \belowdisplayshortskip 6.8\p@ \@plus2\p@ \@minus2\p@
  \belowdisplayskip \abovedisplayskip
  \let\@listi\@listI}
\normalsize
\renewcommand\small{%
%  \@setfontsize\small\@viiipt{11.9}
  \fontsize{8.0pt}{11.9pt}\selectfont
  \abovedisplayskip 10.1\p@ \@plus3\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus\p@
  \belowdisplayshortskip 4.8\p@ \@plus\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
    \topsep 3\p@ \@plus\p@ \@minus\p@
    \parsep 2\p@ \@plus\p@ \@minus\p@
    \itemsep \parsep}
  \belowdisplayskip \abovedisplayskip
}
\renewcommand\footnotesize{%
%  \@setfontsize\footnotesize\@viipt{10.4}
  \fontsize{7.0pt}{10.4pt}\selectfont
  \abovedisplayskip 8.8\p@ \@plus2\p@ \@minus4\p@
  \abovedisplayshortskip \z@ \@plus\p@
  \belowdisplayshortskip 4.4\p@ \@plus\p@ \@minus2\p@
  \def\@listi{\leftmargin\leftmargini
    \topsep 3\p@ \@plus\p@ \@minus\p@
    \parsep 2\p@ \@plus\p@ \@minus\p@
    \itemsep \parsep}
  \belowdisplayskip \abovedisplayskip
}

% multiplier: 1.483
%\renewcommand\scriptsize{\@setfontsize\scriptsize\@vipt{8.9}}
%\renewcommand\tiny{\@setfontsize\tiny\@vpt{7.4}}
%\renewcommand\large{\@setfontsize\large\@xpt{14.8}}
%\renewcommand\Large{\@setfontsize\Large\@xipt{16.3}}
%\renewcommand\LARGE{\@setfontsize\LARGE\@xiipt{17.8}}
%\renewcommand\huge{\@setfontsize\huge\@xivpt{20.7}}
%\renewcommand\Huge{\@setfontsize\Huge\@xxpt{29.7}}
\renewcommand\scriptsize{\fontsize{6.0pt}{8.9pt}\selectfont}
\renewcommand\tiny{\fontsize{5.0pt}{7.4pt}\selectfont}
\renewcommand\large{\fontsize{10.0pt}{14.8pt}\selectfont}
\renewcommand\Large{\fontsize{11.0pt}{16.3pt}\selectfont}
\renewcommand\LARGE{\fontsize{14.0pt}{20.8pt}\selectfont}
\renewcommand\huge{\fontsize{18.0pt}{26.7pt}\selectfont}
\renewcommand\Huge{\fontsize{24.0pt}{35.6pt}\selectfont}

%
% Definition of length
%
\if@twocolumn
\setlength\parindent{9.1\p@}
\else
\setlength\parindent{13.5\p@}
\fi
\setlength\parskip{0\p@}

\marginparsep=0\p@
\marginparwidth=0\p@
\topskip=0\p@
\topmargin=0\p@
\advance\topmargin -1in
\advance\topmargin 52\p@
\headheight=9\p@
\headsep=21\p@
\oddsidemargin=0\p@
\advance\oddsidemargin -1in
\advance\oddsidemargin 19mm
\evensidemargin=0\p@
\advance\evensidemargin -1in
\advance\evensidemargin 19mm
\textwidth=172mm
\textheight=238mm
\footskip=33\p@
\columnsep=7.5mm
%\baselineskip=4mm

\newdimen\abstwidth
\abstwidth=\textwidth
\advance\abstwidth -10mm

\renewcommand{\topfraction}{0.8}
\renewcommand{\bottomfraction}{0.8}
\renewcommand{\dbltopfraction}{0.8}
\renewcommand{\textfraction}{0.1}
\renewcommand{\floatpagefraction}{0.8}
\renewcommand{\dblfloatpagefraction}{0.8}
\setcounter{topnumber}{5}
\setcounter{bottomnumber}{5}
\setcounter{totalnumber}{10}

%
% Definition of sector headings
%
\c@secnumdepth=4
\newsavebox\sect@boxa
\newsavebox\sect@boxb
\newsavebox\sect@boxc
\sbox\sect@boxa{}
\sbox\sect@boxb{}
\sbox\sect@boxc{}
\renewcommand\thesection{\@arabic\c@section.}
\renewcommand\thesubsection{\thesection\@arabic\c@subsection}
\newif\if@sect@num\@sect@numtrue

%\renewcommand\section[1]{\@startsection{section}{1}{%
%    9.1\p@}{4mm \@plus 0.4mm \@minus 0.4mm}{%
%    3.0mm \@plus 0.3mm \@minus 0.3mm}{%
%    \noindent\normalfont\Large\jamssectfont}{%
%    \hskip -1mm#1}}
\def\section{\@ifstar{\@sect@numfalse\@sectA}{%
    \@sect@numtrue\@sectA}}
\def\@sectA{\@ifnextchar[ {\@@sectA}{\@@sectA[0\p@]}}
\def\@@sectA[#1]#2{\vspace{#1}%
  \addpenalty\@secpenalty
%  \ifnum\the\c@section>0
  \addvspace{3.5mm \@plus 0.4mm \@minus 0.4mm}
%  \else
%  \vskip -7\p@ % manually adjusted
%  \fi
  \setcounter{subsection}{0}
  \output@sect{section}{#2}\par@org
  \addvspace{2.1mm \@plus 0.2mm \@minus 0.4mm}
}

%\renewcommand\subsection[1]{\@startsection{subsection}{2}{%
%    9.1\p@}{2mm \@plus 0.2mm \@minus 0.2mm}{%
%    1.5mm \@plus 0.15mm \@minus 0.15mm}{%
%    \normalfont\large\jasmasectfont}{\hskip -1mm#1}}
\def\subsection{\@ifstar{\@sect@numfalse\@subsectA}{%
    \@sect@numtrue\@subsectA}}
\def\@subsectA{\@ifnextchar[ {\@@subsectA}{\@@subsectA[0\p@]}}
\def\@@subsectA[#1]#2{\vspace{#1}%
  \addpenalty\@secpenalty
  \addvspace{1.8mm \@plus 0.2mm \@minus 0.4mm}
  \setcounter{subsubsection}{0}
  \output@sect{subsection}{#2}\par@org
  \addvspace{1.5mm \@plus 0.15mm \@minus 0.2mm}
}

%\renewcommand\subsubsection[1]{\@startsection{subsubsection}{3}{%
%    9.1\p@}{2mm \@plus 0.2mm \@minus 0.2mm}{%
%    1.2mm \@plus 0.12mm \@minus 0.12mm}{%
%    \normalfont\large\jasmasectfont}{\hskip -1mm#1}}
\def\subsubsection{\@ifstar{\@sect@numfalse\@subsubsectA}{%
    \@sect@numtrue\@subsubsectA}}
\def\@subsubsectA{\@ifnextchar[ {\@@subsubsectA}{%
    \@@subsubsectA[0\p@]}}
\def\@@subsubsectA[#1]#2{\vspace{#1}%
  \addpenalty\@secpenalty
  \addvspace{2mm \@plus 0.2mm \@minus 0.2mm}
  \setcounter{subsubsubsection}{0}
  \output@sect{subsubsection}{#2}\par@org
  \vspace{1.5mm \@plus 0.15mm \@minus 0.15mm}
}

\newcounter{subsubsubsection}[subsubsection]
\renewcommand\thesubsubsubsection{%
  \global\advance\c@subsubsubsection \@ne%
  \thesubsubsection.\@arabic\c@subsubsubsection}

\def\subsubsubsection{\@ifstar{\@sect@numfalse\@subsubsubsectA}{%
    \@sect@numtrue\@subsubsubsectA}}
\def\@subsubsubsectA{\@ifnextchar[ {\@@subsubsubsectA}{%
    \@@subsubsubsectA[0\p@]}}
\def\@@subsubsubsectA[#1]#2{\vspace{#1}%
  \addpenalty\@secpenalty
  \addvspace{1.5mm \@plus 0.15mm \@minus 0.15mm}
  \output@sect{subsubsubsection}{#2}\par@org
  \vspace{1mm \@plus 0.1mm \@minus 0.1mm}
}

%\global\let\jasmasect=\sffamily
\global\let\jasmasectfont=\bfseries
\def\output@sect#1#2{%
  \def\tempa{#1}
  \def\secti{section}
  \def\sectii{subsection}
  \def\sectiii{subsubsection}
  \def\sectiv{subsubsubsection}
  \ifx\tempa\secti
  \if@sect@num
  \global\advance\c@section \@ne
  \sbox\sect@boxa{\normalfont\Large\jasmasectfont\hskip 9.1\p@%
    \thesection\hskip 8\p@}
  \else
  \sbox\sect@boxa{\normalfont\Large\jasmasectfont\hskip 9.1\p@}
  \fi
  \sbox\sect@boxb{\normalfont\Large\jasmasectfont #2}
  \else
  \ifx\tempa\sectii
  \if@sect@num
  \global\advance\c@subsection \@ne
  \sbox\sect@boxa{\normalfont\large\jasmasectfont\hskip 9.1\p@%
    \thesubsection\hskip 7\p@}
  \else
  \sbox\sect@boxa{\normalfont\large\jasmasectfont\hskip 9.1\p@}
  \fi
  \sbox\sect@boxb{\normalfont\large\jasmasectfont #2}
  \else
  \ifx\tempa\sectiii
  \if@sect@num
  \global\advance\c@subsubsection \@ne
  \sbox\sect@boxa{\normalfont\large\jasmasectfont\hskip 9.1\p@%
    \thesubsection.\@arabic\c@subsubsection\hskip 7\p@}
  \else
  \sbox\sect@boxa{\normalfont\large\jasmasectfont\hskip 9.1\p@}
  \fi
  \sbox\sect@boxb{\normalfont\large\jasmasectfont #2}
  \else
  \ifx\tempa\sectiv
  \if@sect@num
  \global\advance\c@subsubsubsection \@ne
  \sbox\sect@boxa{\normalfont\jasmasectfont\hskip 9.1\p@%
    \thesubsubsection.\@arabic\c@subsubsubsection\hskip 6\p@}
  \else
  \sbox\sect@boxa{\normalfont\jasmasectfont\hskip 9.1\p@}
  \fi
  \sbox\sect@boxb{\normalfont\jasmasectfont #2}
  \fi% \ifx\tempa\sectiv
  \fi% \ifx\tempa\sectiii\else
  \fi% \ifx\tempa\sectii\else
  \fi% \ifx\tempa\secti\else
  \sbox\sect@boxc{\usebox\sect@boxa\usebox\sect@boxb}
  \ifdim\wd\sect@boxc >\hsize
  \newdimen\tempb
  \newdimen\tempc
  \tempb\hsize
  \tempc\wd\sect@boxa
  \advance\tempb -\tempc
  \ifx\tempa\secti
  \if@sect@num
  {\noindent\normalfont\Large\jasmasectfont\hskip 9.1\p@\thesection%
    \hskip 8\p@\parbox[t]{\tempb}{#2}\par@org}
  \else
  {\noindent\normalfont\Large\jasmasectfont\hskip 9.1\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \fi
  \else
  \ifx\tempa\sectii
  \if@sect@num
  {\noindent\normalfont\large\jasmasectfont\hskip 9.1\p@\thesubsection%
    \hskip 7\p@\parbox[t]{\tempb}{#2}\par@org}
  \else
  {\noindent\normalfont\large\jasmasectfont\hskip 9.1\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \fi
  \else
  \ifx\tempa\sectiii
  \if@sect@num
  \noindent{\normalfont\large\jasmasectfont\hskip 9.1\p@%
    \thesubsection.\@arabic\c@subsubsection\hskip 7\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \else
  {\noindent\normalfont\large\jasmasectfont\hskip 9.1\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \fi
  \else
  \ifx\tempa\sectiv
  \if@sect@num
  \noindent{\normalfont\jasmasectfont\hskip 9.1\p@%
    \thesubsubsection.\@arabic\c@subsubsubsection\hskip 6\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \else
  {\noindent\normalfont\jasmasectfont\hskip 9.1\p@%
    \parbox[t]{\tempb}{#2}\par@org}
  \fi
  \fi% \ifx\tempa\sectiv
  \fi% \ifx\tempa\sectiii\else
  \fi% \ifx\tempa\sectii\else
  \fi% \ifx\tempa\secti\else
  \else
  %\noindent\usebox\sect@boxc\par@org
  \ifx\tempa\secti
  {\noindent\normalfont\Large\jasmasectfont\hbox{\usebox\sect@boxc}\par@org}
  \else
  {\noindent\normalfont\large\jasmasectfont\hbox{\usebox\sect@boxc}\par@org}
  \fi
  \fi% \ifdim\wd\sect@boxc >\hsize\else
  \par@org
}

%
% Redefine \@startsection
%
%\def\@startsection#1#2#3#4#5#6{%
%  \if@noskipsec \leavevmode \fi
%  \par@org
%  \@tempskipa #4\relax
%  \@afterindenttrue
%  \ifdim \@tempskipa <\z@
%  \@tempskipa -\@tempskipa \@afterindentfalse
%  \fi
%  \if@nobreak
%  \everypar{}%
%  \else
%  \addpenalty\@secpenalty
%  \ifnum\the\c@section>0
%  \addvspace\@tempskipa
%  \else
%  \vskip -7\p@ % manually adjusted
%  \fi
%  \fi
%  \@ifstar
%  {\@ssect{#3}{#4}{#5}{#6}}%
%  {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}
%}

\def\acknowledge#1{\par@org%
  \vspace{4mm \@plus 0.4mm \@minus 0.4mm}
  {{\noindent\normalfont\Large\jasmasectfont #1}\par@org}
  \vspace{1.5mm \@plus 0.15mm \@minus 0.15mm}
}
\def\reference#1{\par@org%
  \vspace{4mm \@plus 0.4mm \@minus 0.4mm}
  {\centering{\noindent\normalfont\Large\jasmasectfont #1}\par@org}
  \vspace{-3mm}
  \vspace{1.5mm \@plus 0.15mm \@minus 0.15mm}
}

%
% Definition of Appendices
%
\def\appendix{\par@org%
  \setcounter{section}{0}
  \setcounter{subsection}{0}
  \@ifnextchar [{\@appd}{\@appd[1]}
}
\newif\if@appd@one\@appd@onefalse
\def\@appd[#1]#2{%
  \def\tempa{}
  \def\tempb{#1}
  \def\tempc{1}
  \ifx\tempa\tempb % \ifx\tempa\tempb
  \@appd@onetrue
  % #1 == null
  \else
  % #1 != null
  \ifx\tempb\tempc
  \@appd@onetrue
  \fi
  \ifnum\tempb>\@ne
  \vskip 4mm \@plus 1ex \@minus 0.2ex
  {\centering{\noindent\normalfont\Large\jasmasectfont Appendices}\par@org}
  \vskip 1.5mm \@plus 0.2ex
  \else
  \vskip 4mm \@plus 1ex \@minus 0.2ex
  {\centering{\noindent\normalfont\Large\jasmasectfont Appendix#2}\par@org}
  \vskip 1.5mm \@plus 0.2ex
  \fi
  \fi
}
\def\append#1{
  \advance\c@section \@ne
  \if@appd@one
  \par@org%
%  {\noindent\normalfont\large\jasmasectfont%
%    Appendix}
  \else
  \par@org%
  \vskip 2mm \@plus 0.2mm \@minus 0.2mm
  {\noindent\normalfont\Large\jasmasectfont%
    Appendix \@arabic\c@section}
  \vskip 1.5mm \@plus 0.15mm
  \fi
}
\def\subappend#1{\par@org%
  \advance\c@subsection \@ne
  \if@appd@one
  \par@org%
  \else
    \vskip 2mm \@plus 0.2mm \@minus 0.2mm
  {\noindent\normalfont\large\jasmasectfont%
    Appendix \@arabic\c@section.\@arabic\c@subsection}
  \vskip 1.5mm \@plus 0.2mm
  \fi
}

%
% Definition of two-column width equation environment
%

\newif\if@isonecoleqn\@isonecoleqnfalse
\newcount\c@saveeqnum
\gdef\saveoneeqn{}
\newenvironment{onecoleqn}[1][\the\c@equation]{%
  \begin{table*}
    \def\tempa{#1}
%    \def\tempb{#2}
    \newcount\c@tempa
    \newcount\c@tempb
    \c@tempa#1
    \ifnum\the\c@tempa>\the\c@equation
    \advance\c@tempa \m@ne
    \fi
    \c@tempb\c@tempa
    \global\c@saveeqnum\c@equation% push \c@equation to \c@saveeqnum
    \global\c@equation\c@tempa% substituting \c@tempa into \c@equation
    \global\@isonecoleqntrue% indicating two-column width eq.
    \begin{eqnarray}% may change to another environment
%      \ifx\tempb\@empty
%      \else
%      \label{#2}% for crossreference
%      \fi
    }{\end{eqnarray}
    \vskip 1mm% manually adjusted
    \centering\rule{0.8\textwidth}{0.2pt}% horizontal rule
%
% saving the used eq. numbers with -1 decrement into \saveoneeqn
%
    \loop% begin loop
    \ifnum\the\c@tempa<\the\c@equation
    \ifx\saveoneeqn\@empty% if \saveoneeqn=empty
    \global\edef\saveoneeqn{\the\c@tempa}
    \else% \ifx\saveoneeqn\@empty
    \global\edef\saveoneeqn{\saveoneeqn,\the\c@tempa}
    \fi% \ifx\saveoneeqn\@empty\else
    \advance\c@tempa \@ne
    \repeat% \ifnum\the\c@tempa<\the\c@equation
%
    \advance\c@tempb -\c@saveeqnum
    \ifnum\the\c@tempb=\z@% consider the ordinally eq. numbering
    \else% consider existence of eq. numbering gap
    \global\c@equation\c@saveeqnum
    \fi
    \global\@isonecoleqnfalse
  \end{table*}
  \global\advance\c@table \m@ne
}

\renewcommand\theequation{%
  \@arabic\c@equation
  \if@isonecoleqn
  \else
  \protect\@findeqnum
  \fi
  \ifnum\the\c@parentequation>0
  \global\c@parentequation=0
  \fi
}

\def\@findeqnum{%
  \ifnum\the\c@parentequation>0
  \else
  \@for\member:=\saveoneeqn\do{%
    \ifnum\the\c@equation=\member
    \global\advance\c@equation \@ne
    \fi
  }%
  \fi
}

%
% Redefinition of figures and tables
%
\def\fnum@figure{Fig.~\thefigure}
\def\fnum@table{Table~\thetable}
\abovecaptionskip 2mm \@plus 0.2mm \@minus 0.2mm
\belowcaptionskip 2mm \@plus 0.2mm \@minus 0.2mm
\abovedisplayskip 4mm \@plus 0.4mm \@minus 0.4mm
\belowdisplayskip 3.5mm \@plus 0.35mm \@minus 0.35mm

\newif\if@isfigure\@isfiguretrue
\renewenvironment{figure}{%
  \global\@isfiguretrue
  \@float{figure}}{\end@float}
\renewenvironment{figure*}{%
  \global\@isfiguretrue
  \@dblfloat{figure}}{\end@dblfloat}
\renewenvironment{table}{%
  \global\@isfigurefalse
  \@float{table}}{\end@float}
\renewenvironment{table*}{%
  \global\@isfigurefalse
  \@dblfloat{table}}{\end@dblfloat}

\long\def\@makecaption#1#2{%
  \addvspace\abovecaptionskip
  \if@isfigure
  \vskip -0.5\baselineskip% manually adjusted
  \fi
  \newdimen\tempa
  \newdimen\tempb
  \newdimen\tempc
  \sbox\@tempboxa{{\bf #1}}
  \tempc\wd\@tempboxa
  \if@isfigure
  \tempa=12mm
  \else
  \tempa=14mm
  \fi
  \tempb\tempa
  \advance\tempb -\tempc
  \sbox\@tempboxa{{\bf #1}\hskip \tempb%
    \baselineskip 0.8\normalbaselineskip #2}
  \ifdim \wd\@tempboxa >\hsize
  \tempc\hsize
  \advance\tempc -\tempa
  {\bf #1}\hskip \tempb\parbox[t]{\tempc}{\mbox{}%
    \baselineskip 0.8\normalbaselineskip%
    #2}\par@org\vskip 2.5\p@% manually adjusted
  \else
  \global \@minipagefalse
  \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}
  \fi
  \addvspace\belowcaptionskip
}

\newenvironment{figcenter}[1][tb]{%
  \newif\if@skip@below\@skip@belowfalse
  \def\tempa{#1}
  \def\tempb{b}
  \ifx\tempa\tempb
  \@skip@belowtrue
  \else
  \def\tempb{bt}
  \ifx\tempa\tempb
  \@skip@belowtrue
  \else
  \fi
  \fi
  \if@skip@below
  \begin{figure}[#1]
    \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
    \else
    \begin{figure}[tb]
      \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
      \fi
      \centering}{%
      \if@skip@below
      \vskip -\belowcaptionskip
      \fi
    \end{figure}
%    \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
  }

\newenvironment{figcenter*}[1][tb]{%
  \begin{figure*}[#1]
    \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
    \centering}{\end{figure*}
%  \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
}
\newenvironment{tabcenter}[1][tb]{\par@org%
  \begin{table}[#1]
    \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
    \centering}{\end{table}
%  \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
}
\newenvironment{tabcenter*}[1][tb]{%
  \begin{table*}[#1]
    \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
    \centering}{\end{table*}
%  \addvspace{6mm \@plus 0.6mm \@minus 0.6mm}
}

\def\btref#1{%
  {\bf \mbox{Table}~\ref{#1}}}
\def\bfref#1{%
  {\bf \mbox{Fig.}~\ref{#1}}}

%
% Reference numbering in References section
%
\renewcommand\bibnumfmt[1]{#1)}

%
% Redefine thebibliography environment
%
\renewenvironment{thebibliography}[1]{
  \reference{References}%
  \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
  \list{\@biblabel{\small\@arabic\c@enumiv}}%  
  {\settowidth\labelwidth{\@biblabel{#1}}%
    \small\itemsep=\z@\parsep=\z@%
    \leftmargin\labelwidth
%    \advance\leftmargin\labelsep
    \@openbib@code
    \usecounter{enumiv}%
    \let\p@enumiv\@empty
    \renewcommand\theenumiv{\@arabic\c@enumiv}}%
  \sloppy
  \clubpenalty4000
  \@clubpenalty \clubpenalty
  \widowpenalty4000%
  \sfcode`\.\@m}{
  \def\@noitemerr
  {\@latex@warning{Empty `thebibliography' environment}}%
  \endlist
}

%
% Definition of footnote rule
%
\footnotesep=10\p@
\let\footnoterule@org\footnoterule
\newcommand{\footnoterule@jasma}{
  \vskip 1\p@
  \noindent\rule{\textwidth}{0.4\p@}
%  \vskip 2\p@
  \vskip 6\p@
}

%
% Definition of make footnote space for the second column
%
\newsavebox{\thanks@box}
\global\sbox{\thanks@box}{}
\newsavebox{\fn@box@one}
\global\sbox{\fn@box@one}{}
\newsavebox{\fn@box@two}
\global\sbox{\fn@box@two}{}

\newdimen\thanks@ht % height of \thanks@box
\newdimen\thanks@wd % width of \thanks@box
\thanks@ht=0\p@ % init
\setlength\thanks@wd{\textwidth} % init
\advance\thanks@wd -24\p@ % for left side margin
\advance\thanks@wd -2mm % for right side margin
\newdimen\fn@box@one@ht
\fn@box@one@ht=0\p@

\newcount\aff@count % new counter
\newcount\aff@ii % new counter
\newcount\aff@find % new counter
\newif\if@aff\@afftrue % new if

\global\aff@count=\z@ % init
\global\aff@ii=\z@ % init

\gdef\affsave{} % global

% find affiliation duplication
\def\findaff#1{%
  \aff@find=\z@%
  \def\test@aff{#1}%
  \@afftrue%  assuming TRUE
  \@for\member:=\affsave\do{%
    \if@aff%
    \advance\aff@find \@ne%
    \ifx\test@aff\member%  find dupication
    \@afffalse%  change to FALSE
    \fi%
    \fi%
  }%
  \if@aff%  if TRUE, then add #1 to \affsave
  \ifx\affsave\@empty%  if empty
  \global\edef\affsave{#1}%
  \else%  else
  \global\edef\affsave{\affsave,#1}%  append
  \fi%
  \fi%  if FALSE, then do nothing = assuming duplication
}

\def\affcomma{%
%$^{,}\hskip -2\p@$
$^{,}\hskip -3\p@$
}

%
% define command \affil[#1]{#2}
%
\def\affil{\@ifnextchar [{\@affil}{\@@affil}}
\def\@affil[#1]#2{%  option [#1] exists
  \def\tempa{}%  returns empty
  \def\tempb{#2}%  returns #2
  % checking whether #2 is empty or not
  % if empty then assuming this is footnotemark at author list.
  % else this is footnote.
  \ifx\tempa\tempb%  \ifx\tempa\tempb
  % #2 == null
  \findaff{#1}%  check affiliation duplication
  \if@aff%  if not duplicated
  \global\advance\aff@ii \@ne%
%  {\small\hskip -3\p@\footnotemark[\aff@ii]}% manually adjusted
  {\small\footnotemark[\aff@ii]}% manually adjusted
  \else%  if dulicated
%  {\small\hskip -3\p@\footnotemark[\aff@find]}% manually adjusted
  {\small\footnotemark[\aff@find]}% manually adjusted
  \fi%
  \else%  \ifx\tempa\tempb
  % #2 != null
  % save footnote to name of affil1, affil2, ...
  \global\advance\aff@count \@ne%
  \expandafter\gdef\csname affil\the\aff@count\endcsname{#2}%
  \fi%  \ifx\tempa\tempb
}

%
% define command \affil{#2}
%
\def\@@affil#1{%  option [#1] does not exist
  \def\tempa{}%
  \def\tempb{#1}%
  \ifx\tempa\tempb%  \ifx\tempa\tempb
  % #1 == null
  % this means \affil{} in this case
  % this should not be used but works as the footnotemark at the
  % aouthor list
  \global\advance\aff@ii \@ne%
  {\small\hskip -3\p@\footnotemark[\aff@ii]}% manually adjusted
  \else%  \ifx\tempa\tempb
  % #1 != null
  % save footnote to name of affil1, affil2, ...
  \global\advance\aff@count \@ne%
  \expandafter\gdef\csname affil\the\aff@count\endcsname{#1}%
  \fi%  \ifx\tempa\tempb
}
%
% define command \email{#1}
%
\def\email#1{\gdef\@email{(E-mail: #1)}}
\def\@email#1{\csname #1\endcsname}

%
% define actual footnotes
%
\newdimen\add@footnote@ht
\def\@footnotes{%
  \global\add@footnote@ht=0pt
  \newdimen\emailwd
  \emailwd=-\fnmarkwidth
  \advance\emailwd 2mm
  \global\let\footnoterule\footnoterule@jasma
  \footnotesep=6.5pt
  \baselineskip=8pt
  \newdimen\@tempfootwd
%
  \ifnum\the\aff@count>\@ne % \ifnum\the\aff@count>\@ne
    \aff@ii=\z@
    \loop
    \ifnum\the\aff@ii<\the\aff@count
      \advance\aff@ii \@ne
      \footnotetext[\the\aff@ii]{\parbox[t]{\thanks@wd}{%
        \baselineskip=8pt
        \csname affil\the\aff@ii\endcsname}
      }
      {%
      \sbox\@tempboxa{\footnotesize\csname affil\the\aff@ii\endcsname}
      \@tempfootwd\wd\@tempboxa
      \loop
      \ifdim\@tempfootwd>\thanks@wd
        \global\advance\add@footnote@ht\baselineskip
        \advance\@tempfootwd -\thanks@wd
      \repeat
      }
    \repeat
    \def\thefootnote{\@fnsymbol\c@footnote}
    \footnotetext[0]{\hskip \emailwd\@email}
  \else % \ifnum\the\aff@count>\@ne
    \ifnum\the\aff@ii=\@ne
      \footnotetext[\the\aff@ii]{\parbox[t]{\thanks@wd}{%
        \baselineskip=8pt
        \csname affil\the\aff@ii\endcsname}
      }
      {%
      \sbox\@tempboxa{\footnotesize\csname affil\the\aff@ii\endcsname}
      \@tempfootwd\wd\@tempboxa
      \loop
      \ifdim\@tempfootwd>\thanks@wd
        \global\advance\add@footnote@ht\baselineskip
        \advance\@tempfootwd -\thanks@wd
      \repeat
      }
      \def\thefootnote{\@fnsymbol\c@footnote}
      \footnotetext[0]{\hskip \emailwd\@email}
    \else
      \def\thefootnote{\@fnsymbol\c@footnote}
      \footnotetext[0]{\hskip \emailwd
        \advance\thanks@wd 8mm
        \parbox[t]{\thanks@wd}{%
          \baselineskip=8pt
          \csname affil\the\aff@count\endcsname}}
      {%
      \sbox\@tempboxa{\footnotesize\csname affil\the\aff@count\endcsname}
      \@tempfootwd\wd\@tempboxa
      \loop
      \ifdim\@tempfootwd>\thanks@wd
        \global\advance\add@footnote@ht\baselineskip
        \advance\@tempfootwd -\thanks@wd
      \repeat
      }
      \footnotetext[0]{\hskip \emailwd\@email}
    \fi
  \fi % \ifnum\the\aff@count>\@ne
}

%
% input height of actual footnotes to \thanks@ht
%
\def\@setheight@footnote{
  \ifnum\the\aff@count>\z@%
  \sbox{\thanks@box}{%
    \begin{minipage}{\thanks@wd}%
      \@footnotes%
    \end{minipage}%
  }
  \global\thanks@ht\ht\thanks@box%
  \global\advance\thanks@ht\add@footnote@ht
  % for Debug
  % \usebox{\thanks@box}
  \@footnotes
  \fi%  \ifnum\the\aff@count>\z@
}

%
%
%
\let\@makefnmark@org\@makefnmark
\def\@makefnmark@jasma{\@textsuperscript{\normalfont\@thefnmark}}
\let\@makefnmark\@makefnmark@jasma
\let\@makefntext@org\@makefntext
\def\@makefntext@jasma#1{\small\noindent\hbox to \fnmarkwidth{%
  \raggedright\normalfont\small\@thefnmark\hss}#1}
\let\@makefntext\@makefntext@jasma

%
% definition of command \firstfootnotespace for the second column
% at the first page.
%
\def\firstfootnotespace{\@ifnextchar[{\@firstfootnotespace}{%
    \@firstfootnotespace[\z@]}}
\def\@firstfootnotespace[#1]{%
  \advance\thanks@ht #1%
  \global\let\footnoterule\relax%
%  \advance\thanks@ht 3.4\p@ % space of the footnoterule
  \advance\thanks@ht 7.4\p@ % space of the footnoterule
%  \advance\thanks@ht 4\p@ % additional margin
%  \insert\footins{\vbox to \thanks@ht {}}%
  \def\thefootnote{\@fnsymbol\c@footnote}
  \footnotetext[0]{\mbox{\rule[\z@]{\z@}{\thanks@ht}}}
  \c@footnote\z@
}
%
\def\addfootnotespace#1{%
  \global\let\footnoterule\relax%
  \def\thefootnote{\@fnsymbol\c@footnote}
  \newdimen\additional@ht
  \additional@ht=\thanks@ht
  \advance\additional@ht #1
  \footnotetext[0]{\mbox{\rule[\z@]{\z@}{\additional@ht}}}
  \@onfirstpagefalse
  \c@footnote\z@
}
%
\let\footnote@org\footnote
%
%\def\footnote{\@ifnextchar[{\footnote@mod}{%
%    \footnote@@mod}}
%\def\footnote@mod[#1]#2{%
%  \global\let\footnoterule\footnoterule@jasma
%  \if@cmfont
%    \thefootnote@three
%  \else
%    \thefootnote@four
%  \fi
%  \footnote@org[#1]{#2}%
%  \sbox{\fn@box@two}{%
%    \begin{minipage}{\thanks@wd}%
%      \usebox{\fn@box@one}%
%      \footnotetext[#1]{#2}%
%    \end{minipage}%
%  }%
%  \sbox{\fn@box@one}{\usebox{\fn@box@two}}
%  \global\@ftruletrue
%}
%
%\def\footnote@@mod#1{%
%  \global\let\footnoterule\footnoterule@jasma
%  \if@cmfont
%    \thefootnote@three
%  \else
%    \thefootnote@four
%  \fi
%  \footnote@org{#1}%
%  \sbox{\fn@box@two}{%
%    \begin{minipage}{\thanks@wd}%
%      \usebox{\fn@box@one}%
%      \footnotetext{#1}%
%    \end{minipage}%
%  }%
%  \sbox{\fn@box@one}{\usebox{\fn@box@two}}
%%  \usebox{\fn@box@one}
%  \global\@ftruletrue
%}
%
\def\footnoteinit{%
  \let\footnoterule\footnoterule@org
%  \let\footnoterule\footnoterule@jasma
  \thefootnote@set
}
%
%  for going back to original \footnote
%
\def\footnote{%
  \footnoteinit
  \footnote@org
}

%
% additional commands
%
% command for reserved lines at the top
\def\reserve#1{\gdef\@reserve{#1}}
% abstract command
\def\abstract#1{\gdef\@abstract{#1}}
% key words
\def\keywords#1{\gdef\@keywords{#1}}
\def\keywords@heading{{\textbf{\small Keyword(s):\ }}}
% dates
\def\jasmadate#1#2#3{%
  \def\tempa{#1}%
  \def\tempb{#2}%
  \def\tempc{#3}%
  \gdef\@jasmadate{%
    \ifx\tempa\@empty{}\else%
      {Received \tempa}%
    \fi%
    \ifx\tempb\@empty{}\else%
      {; Accepted \tempb}%
    \fi%
    \ifx\tempc\@empty{}\else
      {; Published \tempc}%
    \fi
    }
  }

%
% add footnotespace automatically to the second column
% at the first page
%
\global\newdimen\fnmarkwidth
\newif\if@onfirstpage\@onfirstpagefalse
\newif\if@inbody\@inbodyfalse
\if@twocolumn
  \@onfirstpagetrue
\else
  \@onfirstpagefalse
\fi
\newif\if@ftrule\@ftrulefalse
\let\par@org\par
\def\par{%
\if@inbody
  \if@onfirstpage
    \if@firstcolumn
      \par@org
    \else
      \par@org
      \firstfootnotespace[0pt]
      \@onfirstpagefalse%
%      \c@footnote\z@%
    \fi
  \else
    \par@org%
  \fi
\else
%   \if@firstcolumn
    \par@org%
%   \else
%     \if@ftrule
%       \global\fn@box@one@ht\ht\fn@box@one
% %      \addfootnotespace{\fn@box@one@ht}\par@org
%       \c@footnote\z@
%       \@ftrulefalse
%     \else
%       \par@org
%     \fi
%   \fi
\fi
}

%
% maketitle
%
\def\thefootnote@one{%
  \def\thefootnote{\hskip -1.9mm\small\@arabic\c@footnote}% manually adjusted
  \settowidth{\fnmarkwidth}{\normalfont\small 99\ }%
}
\def\thefootnote@two{%
  \def\thefootnote{\hskip -0.8mm\small\@arabic\c@footnote}% manually adjusted
  \settowidth{\fnmarkwidth}{\normalfont\small 99\ \ }%
}
\def\thefootnote@three{%
  \def\thefootnote{\hskip -1.9mm\protect\raisebox{0.5\p@}{%
    \footnotesize\@arabic\c@footnote}}%
\settowidth{\fnmarkwidth}{\normalfont\small 99\ }%
}
\def\thefootnote@four{%
  \def\thefootnote{\hskip -0.8mm\protect\raisebox{0.5\p@}{%
    \footnotesize\@arabic\c@footnote}}%
\settowidth{\fnmarkwidth}{\normalfont\small 99\ \ }%
}

\def\maketitle{\par@org
  \if@cmfont
    \thefootnote@one
    \global\let\thefootnote@set\thefootnote@three
  \else
    \thefootnote@two
    \global\let\thefootnote@set\thefootnote@four
  \fi
  \begingroup 
  \if@twocolumn
  \ifnum\col@number=\@ne
  \@maketitle % calling \@maketitle
  \else
  \twocolumn[\@maketitle] % calling \@maketitle
  \fi
  \else
  \newpage
  \global\@topnum\z@
  \@maketitle % calling \@maketitle
  \fi
  \@setheight@footnote % print footnotes
  \endgroup
  \thispagestyle{jasmatop} % page style of the first page
  \setcounter{footnote}{0}
  \let\maketitle\relax
  \let\@maketitle\relax
  \gdef\@reserve{}
  \gdef\@title{}
  \gdef\@author{}
  \gdef\@thanks{}
  \gdef\@abstract{}
  \gdef\@keywords{}
  \gdef\@jasmadate{}
  \let\@title\@empty
  \let\@author\@empty
  \let\thanks\@empty
  \let\@abstract\@empty
  \let\@keywords\@empty
  \let\jasmadate\@empty
  \let\title\relax
  \let\author\relax
  \let\thanks\relax
  \let\abstract\relax
  \let\keywords\relax
  \let\jasmadate\relax
  \global\@inbodytrue
}

%
% \@maketitle
%
\def\@maketitle{
  \newpage\null
  \@ifundefined{@reserve}{}{%
  \setlength{\baselineskip}{11\p@}
  {\noindent\large\textbf{\@reserve}}}%  print reserved lines
  \begin{center}
    \vskip 7\p@
    \setlength{\baselineskip}{20\p@}
    {\LARGE\textbf{\@title}}%  print title
  \end{center}
  \par@org
  \begin{center}
    \vskip 10\p@
    \setlength{\baselineskip}{17\p@}
    {\large
      \@author%  print author list
    }
  \end{center}
  \par@org
  \@ifundefined{@abstract}{}{%
    \begin{center}
      \vskip 7\p@
      {\small\textbf{Abstract}}%  print abstract
    \end{center}
    \vskip -1\p@ \hskip 5mm
    \parbox{\abstwidth}{\small
      \setlength{\baselineskip}{9.5\p@}
      \setlength{\parindent}{1em}
      \@abstract}}
  \par@org
  \@ifundefined{@keywords}{}{%  print key words
    \begin{list}{\keywords@heading}{
        \setlength{\topsep}{5\p@}
        \settowidth{\labelwidth}{\keywords@heading}
        \setlength{\leftmargin}{\labelwidth}
        \addtolength{\leftmargin}{5mm}
        \if@cmfont
        \addtolength{\leftmargin}{1.5\p@}% manually adjusted
        \else
        \addtolength{\leftmargin}{3\p@}% manually adjusted
        \fi
        \setlength{\rightmargin}{5mm}
        \setlength{\baselineskip}{0.8\normalbaselineskip}}
%    \item{\small\it\@keywords}
    \item{\small\@keywords}
    \end{list}}
  \par@org
  \@ifundefined{@jasmadate}{}{%
    \vskip -3\p@% manually adjusted
    \baselineskip 8\p@%
    \hskip 5mm%
    \parbox{\abstwidth}{\small\@jasmadate}%
  }
  \par@org
  \vskip 10mm \@plus 1ex \@minus 1ex
}

% received and accepted dates
%\def\rdate#1{\gdef\@rdate{#1}}
%\def\adate#1{\gdef\@adate{#1}}
%\def\@rdate{}
%\def\@adate{}
% command to print those dates
%\def\timestamp{%\vskip \baselineskip%
%  \raggedleft{\jasmasectfont{Received \@rdate; Accepted
%      \@adate}
%  }\par\raggedright
%  \immediate\write\@auxout{\string\gdef\string\@lastpage{\number\c@sumpage}}
%%  \immediate\write\@auxout{\string\gdef\string\@lastpage{\number\c@page}}
%}

% for getting total number of pages
\def\writeaux{\immediate\write\@auxout{\string\gdef\string\@lastpage{%
  \number\c@sumpage}}}

% leftmargin of equation
\global\@mathmargin=18.2\p@
% amsmath does not use \mathindent
% \global\mathindent=18.2\p@

%
% Headers and Footers
% even page should be the left side (De facto Standard)
%
\newcount\c@sumpage
\newcount\c@localpage
\newcount\c@temppage
\def\@toppageheader{}

% Abbrebiations
\def\authorabbrev#1{\gdef\@auabbrev{\small\hfil #1\hfil}}
\def\titleabbrev#1{\gdef\@tiabbrev{\small\hfil #1\hfil}}
\def\etal{\newdimen\@bk%
  \settowidth{\@bk}{\ }%
  \hskip -\@bk, \textit{et al.}}

% Article page information
\def\localpage#1{%
  \def\tempa{#1}
  \global\c@localpage\tempa
  \global\c@temppage\c@localpage % use for print local page number
  \global\c@sumpage\c@localpage
}
% for debug
\def\thelocalpage{%
  \the\c@localpage
}

%% \def\toppageheader#1#2#3#4#5{\gdef\@jasmainf{Int. J. Microgravity
%% Sci. Appl.}}
%% #5 is now obsolete since the last page is read from the .aux file.
%\def\toppageheader#1#2#3#4{\gdef\@jasmainf{Int. J. Microgravity
%    Sci. Appl. Vol.\,#1\, No.\,#2\, #3}%
%  \@ifundefined{@lastpage}{\gdef\@lastpage{??}}{}
%  \def\tempa{#4}
%  \global\c@sumpage\tempa
%  \newcount\c@tempb
%  \c@temppage\tempa
%  \c@tempb\tempa
%  \divide\c@tempb \tw@
%  \multiply\c@tempb \tw@
%  \advance\c@temppage -\c@tempb
%  \ifnum\c@temppage>0 % first page is right side
%  \global\c@page\@ne
%%  \gdef\@toppageheader{\small\hfil\@jasmainf\: (#4--#5)}
%  \gdef\@toppageheader{\small\hfil\@jasmainf\: (#4--\@lastpage)}
%  \else % first page is left side
%  \global\c@page\tw@
%%  \gdef\@toppageheader{\small\@jasmainf\: (#4--#5)\hfil}
%%  \gdef\@toppageheader{\small\hfil\@jasmainf\: (#4--#5)}
%  \gdef\@toppageheader{\small\hfil\@jasmainf\: (#4--\@lastpage)}
%  \fi
%%  \global\@temppage\@ne % use for print local page number
%}

\newsavebox{\top@head}
\newdimen\top@head@wd
\def\toppageheader#1#2#3#4#5{%
  \global\c@page\@ne
  \@ifundefined{@lastpage}{\gdef\@lastpage{??}}{}
  \gdef\@topleftfooterinfo{#3/#1(#2)/#4(\@lastpage)}
  \gdef\@articlepage{#4}
  \gdef\@articleyear{#3}
  \gdef\@toppageheader{%
    \hfill\small%
    \sbox{\top@head}{\small\mbox{Int. J. Microgravity Sci. Appl. %
%      \textbf{#1} (#2) (#3) #4}}
      \@@toppageheader{#1}{#2}{#3}{#4}}}%
    \top@head@wd\wd\top@head%
    \parbox{\top@head@wd}{%
      \setlength{\baselineskip}{9.5\p@}%
      Int. J. Microgravity Sci. Appl. %\textbf{#1} (#2) (#3) #4\\%
      \@@toppageheader{#1}{#2}{#3}{#4}\\%
      \def\tempa{#5}%
      \ifx\tempa\@empty{}\else%
        \href{http://dx.doi.org/#5}{DOI: #5}
      \fi
    }
  }
}

\def\@@toppageheader#1#2#3#4{%
  \def\tempa{#1}%
  \def\tempb{#2}%
  \def\tempc{#3}%
  \def\tempd{#4}%
  \ifx\tempa\@empty{}\else%
    {\textbf{\tempa}}%
  \fi%
  \ifx\tempb\@empty{}\else%
    {(\tempb)}%
  \fi%
  \ifx\tempc\@empty{}\else%
    {\ (\tempc)}%
  \fi%
  \ifx\tempd\@empty{}\else%
    {\ \tempd}%
  \fi
}
\newsavebox{\foot@pg}
\sbox{\foot@pg}{\mbox{\footnotesize --\,9999\,--}}
\newdimen\foot@pg@wd
\newdimen\foot@tab
\newdimen\foot@tabi
\newdimen\foot@small
\foot@pg@wd\wd\foot@pg
\foot@tab\textwidth
\advance\foot@tab -\foot@pg@wd
\divide\foot@tab \tw@
\foot@tabi\foot@tab
\foot@small=6mm

%\def\@evenfooter{\footnotesize
%  \hskip -9.1\p@
%  \hskip -4.4\p@
%  \advance\foot@tabi -\foot@small
%  \makebox[\foot@small][l]{\@arabic\c@temppage}%
%%  \makebox[\foot@tabi][l]{\@jasmainf}%
%  \makebox[\foot@pg@wd]{--\,\@arabic\c@sumpage\,--}%
%  \makebox[\foot@tab]{}%
%  \global\advance\c@sumpage \@ne
%  \global\advance\c@temppage \@ne
%}
\def\@evenfooter{\footnotesize%
  \hfill\@articlepage--\@arabic\c@temppage\hfill
  \global\advance\c@sumpage \@ne
  \global\advance\c@temppage \@ne
}

%\def\@oddfooter{\footnotesize
%  \hskip -9.1\p@
%  \hskip -4.4\p@
%%  \makebox[\foot@tab][l]{\@jasmainf}%
%  \makebox[\foot@pg@wd]{--\,\@arabic\c@sumpage\,--}%
%  \makebox[\foot@tab][r]{\@arabic\c@temppage}%
%  \global\advance\c@sumpage \@ne
%  \global\advance\c@temppage \@ne
%}
\def\@oddfooter{\@evenfooter}

\def\ps@jasma{
  \let\@oddfoot\@oddfooter
  \let\@evenfoot\@evenfooter
  \let\@oddhead\@tiabbrev % title abbrev. if odd page
  \let\@evenhead\@auabbrev % authors abbrev. if even page
}

%\gdef\@eventopfooter{\footnotesize
%  \hskip -9.1\p@
%  \hskip -4.4\p@
%  \makebox[\foot@tab][l]{\@arabic\c@temppage}%
%  \makebox[\foot@pg@wd]{--\,\@arabic\c@sumpage\,--}%
%  \makebox[\foot@tab]{}%
%  \global\advance\c@sumpage \@ne
%  \global\advance\c@temppage \@ne
%}
\newsavebox{\top@foot@box}
\newdimen\@ft@spacei
\newdimen\@ft@spaceii
\newdimen\@ft@spaceiii
\newdimen\@ft@spaceiv
\newdimen\@ft@spacev
\def\@eventopfooter{\footnotesize%
  \setlength{\baselineskip}{9.5\p@}%
  \sbox{\top@foot@box}{\footnotesize%
    \@articlepage--\@arabic\c@temppage}
  \@ft@spaceiii\wd\top@foot@box
  \@ft@spaceii\textwidth
  \advance\@ft@spaceii -\@ft@spaceiii
  \divide\@ft@spaceii \tw@
  \@ft@spaceiv=\@ft@spaceii
  \sbox{\top@foot@box}{\footnotesize\mbox{%
    0915-3616/\@topleftfooterinfo}}
  \@ft@spacei\wd\top@foot@box
  \advance\@ft@spaceii -\@ft@spacei
  \sbox{\top@foot@box}{\footnotesize\mbox{%
    \copyright\ \@articleyear\ The Jpn. Soc. Microgravity Appl.}}
  \@ft@spacev\wd\top@foot@box
  \advance\@ft@spaceiv -\@ft@spacev
  \hskip -9.1\p@%
    0915-3616/\@topleftfooterinfo \hskip\@ft@spaceii%
    \@articlepage--\@arabic\c@temppage%
    \hskip\@ft@spaceiv%
    \parbox[t]{\@ft@spacev}{%
      \setlength{\baselineskip}{9.5\p@}%
      \copyright\ \@articleyear\ The Jpn. Soc. Microgravity Appl.\\%
      \href{http://www.jasma.info/journal/}{%
        http://www.jasma.info/journal/}}
  \global\advance\c@sumpage \@ne
  \global\advance\c@temppage \@ne
}

%\def\@oddtopfooter{\footnotesize
%  \hskip -9.1\p@
%  \hskip -4.4\p@
%  \makebox[\foot@tab]{}%
%  \makebox[\foot@pg@wd]{--\,\@arabic\c@sumpage\,--}%
%  \makebox[\foot@tab][r]{\@arabic\c@temppage}%
%  \global\advance\c@sumpage \@ne
%  \global\advance\c@temppage \@ne
%}
\def\@oddtopfooter{\@eventopfooter}

\def\ps@jasmatop{
  \let\@oddfoot\@oddtopfooter
  \let\@evenfoot\@eventopfooter
  \let\@oddhead\@toppageheader
  \let\@evenhead\@oddhead
}

\endinput
